pub enum ButtonState {
Down,
Up,
}Expand description
Describes the state a button is in.
Variants
Down
The button is pressed down.
Often emitted in a mousedown event, see also the MDN documentation on that.
Up
The button is not pressed / was just released.
Often emitted in a mouseup event, see also the MDN documentation on that.
Implementations
Sourceimpl ButtonState
impl ButtonState